@@ -1,18 +1,18 @@
 ( cd opt ; if [ -d httpd ]; then mv httpd httpd.bak ; fi )
 ( cd opt ; rm -rf httpd )
-( cd opt ; ln -sf httpd-2.2.13 httpd )
-if [ -f opt/httpd-2.2.13/bin/apr-1-config ]; then
-( cd opt/httpd-2.2.13/lib ; rm -rf libaprutil-1.so )
-( cd opt/httpd-2.2.13/lib ; ln -sf libaprutil-1.so. libaprutil-1.so )
-( cd opt/httpd-2.2.13/lib ; rm -rf libapr-1.so )
-( cd opt/httpd-2.2.13/lib ; ln -sf libapr-1.so. libapr-1.so )
-( cd opt/httpd-2.2.13/lib ; rm -rf libapr-1.so.0 )
-( cd opt/httpd-2.2.13/lib ; ln -sf libapr-1.so. libapr-1.so.0 )
-( cd opt/httpd-2.2.13/lib ; rm -rf libaprutil-1.so.0 )
-( cd opt/httpd-2.2.13/lib ; ln -sf libaprutil-1.so. libaprutil-1.so.0 )
+( cd opt ; ln -sf httpd-2.2.14 httpd )
+if [ -f opt/httpd-2.2.14/bin/apr-1-config ]; then
+( cd opt/httpd-2.2.14/lib ; rm -rf libaprutil-1.so )
+( cd opt/httpd-2.2.14/lib ; ln -sf libaprutil-1.so. libaprutil-1.so )
+( cd opt/httpd-2.2.14/lib ; rm -rf libapr-1.so )
+( cd opt/httpd-2.2.14/lib ; ln -sf libapr-1.so. libapr-1.so )
+( cd opt/httpd-2.2.14/lib ; rm -rf libapr-1.so.0 )
+( cd opt/httpd-2.2.14/lib ; ln -sf libapr-1.so. libapr-1.so.0 )
+( cd opt/httpd-2.2.14/lib ; rm -rf libaprutil-1.so.0 )
+( cd opt/httpd-2.2.14/lib ; ln -sf libaprutil-1.so. libaprutil-1.so.0 )
 fi
 
-#%% begin initialize httpd-2.2.13-i586-P3
+#%% begin initialize httpd-2.2.14-i586-P1
 # Apache httpd-2.2 web server installer
 export PATH=/bin:/usr/bin:/sbin:/usr/sbin
 export LANG=C
@@ -22,7 +22,7 @@ if [ -r /tmp/SeTT_PX ]; then
   ROOT="`cat /tmp/SeTT_PX`"
 fi
 
-APACI_DIR=$ROOT/opt/httpd-2.2.13
+APACI_DIR=$ROOT/opt/httpd-2.2.14
 HTTPD=httpd
 
 #if [ -d $ROOT/opt/$HTTPD ] ; then
@@ -64,6 +64,11 @@ else
   fi  
 fi
 
+if ! fgrep '# MANPATH	/opt/\*/man' $ROOT/etc/man.conf 1> /dev/null 2>&1; then
+  mv $ROOT/etc/man.conf $ROOT/etc/man.conf.bak
+  sed -e 's%# MANPATH\t/opt/\*/man%MANPATH\t/opt/\*/man%' \
+	$ROOT/etc/man.conf.bak > $ROOT/etc/man.conf
+fi
 
 cd $ROOT/
 
@@ -118,11 +123,12 @@ if [ "$NNAME" != "" ] ; then
         chmod +x $APACI_DIR/bin/mkrsakey.sh
 fi
 sh $APACI_DIR/bin/mkrsakey.sh
-echo "This is a sample implementaion of Apache WebDAV folder."
-echo "Enter password for admin to access WebDAV(DAV-upload) area."
-echo "You will be able to access Web Folder(https://localhost/uploads)"
-echo "with this user(admin) and password(input here)."
-$APACI_DIR/bin/htdigest -c "/opt/httpd/digest.passwd" DAV-upload admin
+
+#echo "This is a sample implementaion of Apache WebDAV folder."
+#echo "Enter password for admin to access WebDAV(DAV-upload) area."
+#echo "You will be able to access Web Folder(https://localhost/uploads)"
+#echo "with this user(admin) and password(input here)."
+#$APACI_DIR/bin/htdigest -c "/opt/httpd/digest.passwd" DAV-upload admin
 
 #
 # symbolic links
